cli

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Version   = "dev"
	Commit    = "none"
	BuildDate = "unknown"
)

These variables are injected at build time via -ldflags.

Functions

func InitConfig

func InitConfig(configPath string)

InitConfig loads config from path (empty = ~/.logr.yaml). Call from run package when building logger from config.

func NewRootCmd

func NewRootCmd() *cobra.Command

Types

This section is empty.

Jump to