Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Version = "dev" Commit = "none" BuildDate = "unknown" )
These variables are injected at build time via -ldflags.
Functions ¶
func InitConfig ¶
func InitConfig(configPath string)
InitConfig loads config from path (empty = ~/.logr.yaml). Call from run package when building logger from config.
func NewRootCmd ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.